# coding: utf-8

"""
    OpenShift API (with Kubernetes)

    OpenShift provides builds, application lifecycle, image content management, and administrative policy on top of Kubernetes. The API allows consistent management of those objects.  All API operations are authenticated via an Authorization bearer token that is provided for service accounts as a generated secret (in JWT form) or via the native OAuth endpoint located at /oauth/authorize. Core infrastructure components may use client certificates that require no authentication.  All API operations return a 'resourceVersion' string that represents the version of the object in the underlying storage. The standard LIST operation performs a snapshot read of the underlying objects, returning a resourceVersion representing a consistent version of the listed objects. The WATCH operation allows all updates to a set of objects after the provided resourceVersion to be observed by a client. By listing and beginning a watch from the returned resourceVersion, clients may observe a consistent view of the state of one or more objects. Note that WATCH always returns the update after the provided resourceVersion. Watch may be extended a limited time in the past - using etcd 2 the watch window is 1000 events (which on a large cluster may only be a few tens of seconds) so clients must explicitly handle the \"watch to old error\" by re-listing.  Objects are divided into two rough categories - those that have a lifecycle and must reflect the state of the cluster, and those that have no state. Objects with lifecycle typically have three main sections:  * 'metadata' common to all objects * a 'spec' that represents the desired state * a 'status' that represents how much of the desired state is reflected on   the cluster at the current time  Objects that have no state have 'metadata' but may lack a 'spec' or 'status' section.  Objects are divided into those that are namespace scoped (only exist inside of a namespace) and those that are cluster scoped (exist outside of a namespace). A namespace scoped resource will be deleted when the namespace is deleted and cannot be created if the namespace has not yet been created or is in the process of deletion. Cluster scoped resources are typically only accessible to admins - resources like nodes, persistent volumes, and cluster policy.  All objects have a schema that is a combination of the 'kind' and 'apiVersion' fields. This schema is additive only for any given version - no backwards incompatible changes are allowed without incrementing the apiVersion. The server will return and accept a number of standard responses that share a common schema - for instance, the common error type is 'metav1.Status' (described below) and will be returned on any error from the API server.  The API is available in multiple serialization formats - the default is JSON (Accept: application/json and Content-Type: application/json) but clients may also use YAML (application/yaml) or the native Protobuf schema (application/vnd.kubernetes.protobuf). Note that the format of the WATCH API call is slightly different - for JSON it returns newline delimited objects while for Protobuf it returns length-delimited frames (4 bytes in network-order) that contain a 'versioned.Watch' Protobuf object.  See the OpenShift documentation at https://docs.openshift.org for more information. 

    OpenAPI spec version: latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class V1BuildTriggerCause(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bitbucket_web_hook': 'V1BitbucketWebHookCause',
        'generic_web_hook': 'V1GenericWebHookCause',
        'github_web_hook': 'V1GitHubWebHookCause',
        'gitlab_web_hook': 'V1GitLabWebHookCause',
        'image_change_build': 'V1ImageChangeCause',
        'message': 'str'
    }

    attribute_map = {
        'bitbucket_web_hook': 'bitbucketWebHook',
        'generic_web_hook': 'genericWebHook',
        'github_web_hook': 'githubWebHook',
        'gitlab_web_hook': 'gitlabWebHook',
        'image_change_build': 'imageChangeBuild',
        'message': 'message'
    }

    def __init__(self, bitbucket_web_hook=None, generic_web_hook=None, github_web_hook=None, gitlab_web_hook=None, image_change_build=None, message=None):
        """
        V1BuildTriggerCause - a model defined in Swagger
        """

        self._bitbucket_web_hook = None
        self._generic_web_hook = None
        self._github_web_hook = None
        self._gitlab_web_hook = None
        self._image_change_build = None
        self._message = None
        self.discriminator = None

        if bitbucket_web_hook is not None:
          self.bitbucket_web_hook = bitbucket_web_hook
        if generic_web_hook is not None:
          self.generic_web_hook = generic_web_hook
        if github_web_hook is not None:
          self.github_web_hook = github_web_hook
        if gitlab_web_hook is not None:
          self.gitlab_web_hook = gitlab_web_hook
        if image_change_build is not None:
          self.image_change_build = image_change_build
        if message is not None:
          self.message = message

    @property
    def bitbucket_web_hook(self):
        """
        Gets the bitbucket_web_hook of this V1BuildTriggerCause.
        BitbucketWebHook represents data for a Bitbucket webhook that fired a specific build.

        :return: The bitbucket_web_hook of this V1BuildTriggerCause.
        :rtype: V1BitbucketWebHookCause
        """
        return self._bitbucket_web_hook

    @bitbucket_web_hook.setter
    def bitbucket_web_hook(self, bitbucket_web_hook):
        """
        Sets the bitbucket_web_hook of this V1BuildTriggerCause.
        BitbucketWebHook represents data for a Bitbucket webhook that fired a specific build.

        :param bitbucket_web_hook: The bitbucket_web_hook of this V1BuildTriggerCause.
        :type: V1BitbucketWebHookCause
        """

        self._bitbucket_web_hook = bitbucket_web_hook

    @property
    def generic_web_hook(self):
        """
        Gets the generic_web_hook of this V1BuildTriggerCause.
        genericWebHook holds data about a builds generic webhook trigger.

        :return: The generic_web_hook of this V1BuildTriggerCause.
        :rtype: V1GenericWebHookCause
        """
        return self._generic_web_hook

    @generic_web_hook.setter
    def generic_web_hook(self, generic_web_hook):
        """
        Sets the generic_web_hook of this V1BuildTriggerCause.
        genericWebHook holds data about a builds generic webhook trigger.

        :param generic_web_hook: The generic_web_hook of this V1BuildTriggerCause.
        :type: V1GenericWebHookCause
        """

        self._generic_web_hook = generic_web_hook

    @property
    def github_web_hook(self):
        """
        Gets the github_web_hook of this V1BuildTriggerCause.
        gitHubWebHook represents data for a GitHub webhook that fired a specific build.

        :return: The github_web_hook of this V1BuildTriggerCause.
        :rtype: V1GitHubWebHookCause
        """
        return self._github_web_hook

    @github_web_hook.setter
    def github_web_hook(self, github_web_hook):
        """
        Sets the github_web_hook of this V1BuildTriggerCause.
        gitHubWebHook represents data for a GitHub webhook that fired a specific build.

        :param github_web_hook: The github_web_hook of this V1BuildTriggerCause.
        :type: V1GitHubWebHookCause
        """

        self._github_web_hook = github_web_hook

    @property
    def gitlab_web_hook(self):
        """
        Gets the gitlab_web_hook of this V1BuildTriggerCause.
        GitLabWebHook represents data for a GitLab webhook that fired a specific build.

        :return: The gitlab_web_hook of this V1BuildTriggerCause.
        :rtype: V1GitLabWebHookCause
        """
        return self._gitlab_web_hook

    @gitlab_web_hook.setter
    def gitlab_web_hook(self, gitlab_web_hook):
        """
        Sets the gitlab_web_hook of this V1BuildTriggerCause.
        GitLabWebHook represents data for a GitLab webhook that fired a specific build.

        :param gitlab_web_hook: The gitlab_web_hook of this V1BuildTriggerCause.
        :type: V1GitLabWebHookCause
        """

        self._gitlab_web_hook = gitlab_web_hook

    @property
    def image_change_build(self):
        """
        Gets the image_change_build of this V1BuildTriggerCause.
        imageChangeBuild stores information about an imagechange event that triggered a new build.

        :return: The image_change_build of this V1BuildTriggerCause.
        :rtype: V1ImageChangeCause
        """
        return self._image_change_build

    @image_change_build.setter
    def image_change_build(self, image_change_build):
        """
        Sets the image_change_build of this V1BuildTriggerCause.
        imageChangeBuild stores information about an imagechange event that triggered a new build.

        :param image_change_build: The image_change_build of this V1BuildTriggerCause.
        :type: V1ImageChangeCause
        """

        self._image_change_build = image_change_build

    @property
    def message(self):
        """
        Gets the message of this V1BuildTriggerCause.
        message is used to store a human readable message for why the build was triggered. E.g.: \"Manually triggered by user\", \"Configuration change\",etc.

        :return: The message of this V1BuildTriggerCause.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this V1BuildTriggerCause.
        message is used to store a human readable message for why the build was triggered. E.g.: \"Manually triggered by user\", \"Configuration change\",etc.

        :param message: The message of this V1BuildTriggerCause.
        :type: str
        """

        self._message = message

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, V1BuildTriggerCause):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
