# coding: utf-8

"""
    OpenShift API (with Kubernetes)

    OpenShift provides builds, application lifecycle, image content management, and administrative policy on top of Kubernetes. The API allows consistent management of those objects.  All API operations are authenticated via an Authorization bearer token that is provided for service accounts as a generated secret (in JWT form) or via the native OAuth endpoint located at /oauth/authorize. Core infrastructure components may use client certificates that require no authentication.  All API operations return a 'resourceVersion' string that represents the version of the object in the underlying storage. The standard LIST operation performs a snapshot read of the underlying objects, returning a resourceVersion representing a consistent version of the listed objects. The WATCH operation allows all updates to a set of objects after the provided resourceVersion to be observed by a client. By listing and beginning a watch from the returned resourceVersion, clients may observe a consistent view of the state of one or more objects. Note that WATCH always returns the update after the provided resourceVersion. Watch may be extended a limited time in the past - using etcd 2 the watch window is 1000 events (which on a large cluster may only be a few tens of seconds) so clients must explicitly handle the \"watch to old error\" by re-listing.  Objects are divided into two rough categories - those that have a lifecycle and must reflect the state of the cluster, and those that have no state. Objects with lifecycle typically have three main sections:  * 'metadata' common to all objects * a 'spec' that represents the desired state * a 'status' that represents how much of the desired state is reflected on   the cluster at the current time  Objects that have no state have 'metadata' but may lack a 'spec' or 'status' section.  Objects are divided into those that are namespace scoped (only exist inside of a namespace) and those that are cluster scoped (exist outside of a namespace). A namespace scoped resource will be deleted when the namespace is deleted and cannot be created if the namespace has not yet been created or is in the process of deletion. Cluster scoped resources are typically only accessible to admins - resources like nodes, persistent volumes, and cluster policy.  All objects have a schema that is a combination of the 'kind' and 'apiVersion' fields. This schema is additive only for any given version - no backwards incompatible changes are allowed without incrementing the apiVersion. The server will return and accept a number of standard responses that share a common schema - for instance, the common error type is 'metav1.Status' (described below) and will be returned on any error from the API server.  The API is available in multiple serialization formats - the default is JSON (Accept: application/json and Content-Type: application/json) but clients may also use YAML (application/yaml) or the native Protobuf schema (application/vnd.kubernetes.protobuf). Note that the format of the WATCH API call is slightly different - for JSON it returns newline delimited objects while for Protobuf it returns length-delimited frames (4 bytes in network-order) that contain a 'versioned.Watch' Protobuf object.  See the OpenShift documentation at https://docs.openshift.org for more information. 

    OpenAPI spec version: latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class V1DeploymentRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'api_version': 'str',
        'exclude_triggers': 'list[str]',
        'force': 'bool',
        'kind': 'str',
        'latest': 'bool',
        'name': 'str'
    }

    attribute_map = {
        'api_version': 'apiVersion',
        'exclude_triggers': 'excludeTriggers',
        'force': 'force',
        'kind': 'kind',
        'latest': 'latest',
        'name': 'name'
    }

    def __init__(self, api_version=None, exclude_triggers=None, force=None, kind=None, latest=None, name=None):
        """
        V1DeploymentRequest - a model defined in Swagger
        """

        self._api_version = None
        self._exclude_triggers = None
        self._force = None
        self._kind = None
        self._latest = None
        self._name = None
        self.discriminator = None

        if api_version is not None:
          self.api_version = api_version
        if exclude_triggers is not None:
          self.exclude_triggers = exclude_triggers
        self.force = force
        if kind is not None:
          self.kind = kind
        self.latest = latest
        self.name = name

    @property
    def api_version(self):
        """
        Gets the api_version of this V1DeploymentRequest.
        APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#resources

        :return: The api_version of this V1DeploymentRequest.
        :rtype: str
        """
        return self._api_version

    @api_version.setter
    def api_version(self, api_version):
        """
        Sets the api_version of this V1DeploymentRequest.
        APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#resources

        :param api_version: The api_version of this V1DeploymentRequest.
        :type: str
        """

        self._api_version = api_version

    @property
    def exclude_triggers(self):
        """
        Gets the exclude_triggers of this V1DeploymentRequest.
        ExcludeTriggers instructs the instantiator to avoid processing the specified triggers. This field overrides the triggers from latest and allows clients to control specific logic. This field is ignored if not specified.

        :return: The exclude_triggers of this V1DeploymentRequest.
        :rtype: list[str]
        """
        return self._exclude_triggers

    @exclude_triggers.setter
    def exclude_triggers(self, exclude_triggers):
        """
        Sets the exclude_triggers of this V1DeploymentRequest.
        ExcludeTriggers instructs the instantiator to avoid processing the specified triggers. This field overrides the triggers from latest and allows clients to control specific logic. This field is ignored if not specified.

        :param exclude_triggers: The exclude_triggers of this V1DeploymentRequest.
        :type: list[str]
        """

        self._exclude_triggers = exclude_triggers

    @property
    def force(self):
        """
        Gets the force of this V1DeploymentRequest.
        Force will try to force a new deployment to run. If the deployment config is paused, then setting this to true will return an Invalid error.

        :return: The force of this V1DeploymentRequest.
        :rtype: bool
        """
        return self._force

    @force.setter
    def force(self, force):
        """
        Sets the force of this V1DeploymentRequest.
        Force will try to force a new deployment to run. If the deployment config is paused, then setting this to true will return an Invalid error.

        :param force: The force of this V1DeploymentRequest.
        :type: bool
        """
        if force is None:
            raise ValueError("Invalid value for `force`, must not be `None`")

        self._force = force

    @property
    def kind(self):
        """
        Gets the kind of this V1DeploymentRequest.
        Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#types-kinds

        :return: The kind of this V1DeploymentRequest.
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """
        Sets the kind of this V1DeploymentRequest.
        Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#types-kinds

        :param kind: The kind of this V1DeploymentRequest.
        :type: str
        """

        self._kind = kind

    @property
    def latest(self):
        """
        Gets the latest of this V1DeploymentRequest.
        Latest will update the deployment config with the latest state from all triggers.

        :return: The latest of this V1DeploymentRequest.
        :rtype: bool
        """
        return self._latest

    @latest.setter
    def latest(self, latest):
        """
        Sets the latest of this V1DeploymentRequest.
        Latest will update the deployment config with the latest state from all triggers.

        :param latest: The latest of this V1DeploymentRequest.
        :type: bool
        """
        if latest is None:
            raise ValueError("Invalid value for `latest`, must not be `None`")

        self._latest = latest

    @property
    def name(self):
        """
        Gets the name of this V1DeploymentRequest.
        Name of the deployment config for requesting a new deployment.

        :return: The name of this V1DeploymentRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this V1DeploymentRequest.
        Name of the deployment config for requesting a new deployment.

        :param name: The name of this V1DeploymentRequest.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, V1DeploymentRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
